# 4genius
- Ravi
- Dheeraj
- Sepi
- Kai

# Run Test
* `pip install -e .`
* `pytest ./tests --cov=src`
* move to project root folder and 'pytest'
* more detial: https://docs.pytest.org/en/stable/goodpractices.html
